// #autoload
// #name = _ZTabMenuHUD
// #category = ZephyrFox's Scripts
// #description = A tab-menu HUD script.
// #version = 0.5
// #date = 02.05.2004
// #status = testing
// #author = Anthony Vrabel
// #warrior = ZephyrFox
// #email = ZephyrFox@hotmail.com
// #web = www.zephyrfox.com
// #credits = Qing, this is based heavily on his QAdminMenu
// #readme = _ZTabMenuHUD.txt
// #include = support/callback.cs
// #include = support/team_tracker.cs
// #include = support/mute_tools.cs

if(!isObject(ZTMHUD))
{
	new ScriptObject(ZTMHUD)
	{
		class 	= ZTMHUD;
		version = "0.5";
	};
}

package ZTabMenuHUD
{
	function OptionsDlg::onWake(%this)
	{
		if (!$ZTabMenuHUDBind)
		{
			$RemapName[$RemapCount] = "ZTabMenuHUD";
			$RemapCmd[$RemapCount]  = "ZTabMenuHUDToggle";
			$RemapCount++;
			$ZTabMenuHUDBind = true;
		}
	
		parent::onWake(%this);
	}

	function handleMissionCallbackMissionInfo(%msgType, %msgString, %missionname, %missiontype, %servername)
	{
		ZTabMenuHUDserverName.setValue(%servername);

		ZTabMenuHUDip.position = (getWord(ZTabMenuHUDserverName.getExtent(), 0) + 15) @ " 7";
		ZTabMenuHUDip.setValue(getRecord($ServerInfo, 1));

		ZTabMenuHUDserverType.setValue(getRecord($ServerInfo, 3));
		ZTabMenuHUDserverModType.setValue(strUpr(getRecord($ServerInfo, 2)) @ " " @ %missiontype);
		ZTabMenuHUDmap.setValue(%missionname);

		parent::handleMissionCallbackMissionInfo(%msgType, %msgString, %missionname, %missiontype, %servername);
	}

	function handleClientJoinTeam(%msgType, %msgString, %clientName, %teamName, %clientId, %teamId)
	{
		%player = $PlayerList[%clientID];

		if(isObject(%player))
		{
			%oldTeamID  = %player.teamId;
			if(%oldTeamID < 0) %oldTeam = 0;
			if(%oldTeamID != %teamID) callback.trigger(plJoinedTeam, %oldTeamID, %teamID, %clientID);
		}

		parent::handleClientJoinTeam(%msgType, %msgString, %clientName, %teamName, %clientId, %teamId);
	}

	function handleClientDrop(%msgType, %msgString, %clientName, %clientId)
	{
		%player = $PlayerList[%clientID];
		callback.trigger(plLeavingGame, %player.teamID, %clientID);

		parent::handleClientDrop(%msgType, %msgString, %clientName, %clientId);
	}
};
activatePackage(ZTabMenuHUD);

function ZTabMenuHUDToggle(%val)
{
	if(%val)
	{
		if($ZTabMenuHUDOn)
		{
			canvas.popDialog(ZTabMenuHUD);
			canvas.setContent(playgui);
		}
		else
		{
			canvas.setContent(panoramagui);

			ZTMHUD.clearOBS();
			ZTMHUD.buildOBS();

			ZTMHUD.clearTeam1();
			ZTMHUD.buildTeam1();

			ZTMHUD.clearTeam2();
			ZTMHUD.buildTeam2();

			canvas.pushDialog(ZTabMenuHUD);
		}
	}
}

function ZTMHUD::setup(%this)
{
	callback.add(CallbackMsgVoteItem, "ZTMHUD.voteItemMessage");
	callback.add(CallbackMsgPlayerPopupItem, "ZTMHUD.playerPopupMessage");
	callback.add(myTeamChanged, "ZTMHUD.buildAll");
	callback.add(plJoinedTeam, "ZTMHUD.plJoinTeam");
	callback.add(plLeavingGame, "ZTMHUD.plLeaveGame");

	new GuiControlProfile ("ZTabMenuHUDProfile")
	{
		opaque = true;
		fillColor = "0 0 0 50";
		fillColorHL = "64 0 0";
		fillColorNA = "150 150 150";
		bitmap = "gui/darkWindow";
	};

	new GuiControlProfile ("ZTabMenuHUDheaderProfile")
	{
		fontType = "Sui Generis";
		fontSize = 22;
		fontColor = "125 150 0";
		autoSizeWidth = true;
		autoSizeHeight = true;
	};

	new GuiControlProfile ("ZTabMenuHUDinfoProfile")
	{
		fontType = "Sui Generis";
		fontSize = 14;
		fontColor = "125 150 0";
		autoSizeWidth = true;
		autoSizeHeight = true;
	};

	exec("scripts/Zeph/_ZTabMenuHUD.gui");

	if(!$pref::ZTabMenuHUDteam1::Column0)
	{
		$pref::ZTabMenuHUDteam1::Column0 = 24;
		$pref::ZTabMenuHUDteam1::Column1 = 200;
		$pref::ZTabMenuHUDteam1::Column2 = 50;
		$pref::ZTabMenuHUDteam1::Column3 = 50;
		$pref::ZTabMenuHUDteam1::Column4 = 50;
		$pref::ZTabMenuHUDteam1::Column5 = 75;
		$pref::ZTabMenuHUDteam1::SortColumnKey = 3;
		$pref::ZTabMenuHUDteam1::SortInc = 0;

		$pref::ZTabMenuHUDteam2::Column0 = 24;
		$pref::ZTabMenuHUDteam2::Column1 = 200;
		$pref::ZTabMenuHUDteam2::Column2 = 50;
		$pref::ZTabMenuHUDteam2::Column3 = 50;
		$pref::ZTabMenuHUDteam2::Column4 = 50;
		$pref::ZTabMenuHUDteam2::Column5 = 75;
		$pref::ZTabMenuHUDteam2::SortColumnKey = 3;
		$pref::ZTabMenuHUDteam2::SortInc = 0;

		$pref::ZTabMenuHUDOBS::Column0 = 24;
		$pref::ZTabMenuHUDOBS::Column1 = 200;
		$pref::ZTabMenuHUDOBS::Column2 = 50;
		$pref::ZTabMenuHUDOBS::Column3 = 50;
		$pref::ZTabMenuHUDOBS::Column4 = 50;
		$pref::ZTabMenuHUDOBS::Column5 = 75;
		$pref::ZTabMenuHUDOBS::SortColumnKey = 3;
		$pref::ZTabMenuHUDOBS::SortInc = 0;
	}

	ZTabMenuHUDBG.extent = (getWord($pref::Video::resolution, 0) - 100) SPC (getWord($pref::Video::resolution, 1) - 100);
	ZTabMenuHUDvote.position = (getWord($pref::Video::resolution, 0) - 400) @ " 0";

	ZTabMenuHUDteam1.addColumn(0, " ", $pref::ZTabMenuHUDteam1::Column0, 24, 24, "center");
	ZTabMenuHUDteam1.addColumn(1, "Player", $pref::ZTabMenuHUDteam1::Column1, 50, 500);
	ZTabMenuHUDteam1.addColumn(2, "Score", $pref::ZTabMenuHUDteam1::Column2, 25, 100, "numeric center");
	ZTabMenuHUDteam1.addColumn(3, "Ping", $pref::ZTabMenuHUDteam1::Column3, 20, 100, "numeric center");
	ZTabMenuHUDteam1.addColumn(4, "PL", $pref::ZTabMenuHUDteam1::Column4, 20, 100, "numeric center");
	ZTabMenuHUDteam1.addColumn(5, "GUID", $pref::ZTabMenuHUDteam1::Column5, 40, 100, "center");

	ZTabMenuHUDteam2.addColumn(0, " ", $pref::ZTabMenuHUDteam2::Column0, 24, 24, "center");
	ZTabMenuHUDteam2.addColumn(1, "Player", $pref::ZTabMenuHUDteam2::Column1, 50, 500);
	ZTabMenuHUDteam2.addColumn(2, "Score", $pref::ZTabMenuHUDteam2::Column2, 25, 100, "numeric center");
	ZTabMenuHUDteam2.addColumn(3, "Ping", $pref::ZTabMenuHUDteam2::Column3, 20, 100, "numeric center");
	ZTabMenuHUDteam2.addColumn(4, "PL", $pref::ZTabMenuHUDteam2::Column4, 20, 100, "numeric center");
	ZTabMenuHUDteam2.addColumn(5, "GUID", $pref::ZTabMenuHUDteam2::Column5, 40, 100, "center");

	ZTabMenuHUDOBS.addColumn(0, " ", $pref::ZTabMenuHUDOBS::Column0, 24, 24, "center");
	ZTabMenuHUDOBS.addColumn(1, "Player", $pref::ZTabMenuHUDOBS::Column1, 50, 500);
	ZTabMenuHUDOBS.addColumn(2, "Score", $pref::ZTabMenuHUDOBS::Column2, 25, 100, "numeric center");
	ZTabMenuHUDOBS.addColumn(3, "Ping", $pref::ZTabMenuHUDOBS::Column3, 20, 100, "numeric center");
	ZTabMenuHUDOBS.addColumn(4, "PL", $pref::ZTabMenuHUDOBS::Column4, 20, 100, "numeric center");
	ZTabMenuHUDOBS.addColumn(5, "GUID", $pref::ZTabMenuHUDOBS::Column5, 40, 100, "center");
}

function ZTMHUD::buildTeam1(%this)
{
	ZTabMenuHUDteam1Name.setValue(teamtracker.teamName[1]);

	if(teamtracker.numTeams > 1)
	{
		for(%i=0; %i<teamtracker.teamGroup[1].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[1].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam1.addRow(%clientId, %text);
		}

		ZTabMenuHUDteam1.sort();
	}
	else
	{
		for(%i=0; %i<teamtracker.teamGroup[1].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[1].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam1.addRow(%clientId, %text);
		}

		for(%i=0; %i<teamtracker.teamGroup[2].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[2].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam1.addRow(%clientId, %text);
		}

		ZTabMenuHUDteam1.sort();
	}
}

function ZTMHUD::buildTeam2(%this)
{
	if(teamtracker.numTeams > 1)
	{
		ZTabMenuHUDteam2Name.setValue(teamtracker.teamName[2]);

		for(%i=0; %i<teamtracker.teamGroup[2].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[2].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam2.addRow(%clientId, %text);
		}

		ZTabMenuHUDteam2.sort();
	}
	else ZTMHUD.clearTeam2();
}

function ZTMHUD::buildOBS(%this)
{
	ZTabMenuHUDOBSname.setValue(teamtracker.teamName[0]);

	for(%i=0; %i<teamtracker.teamGroup[0].getCount(); %i++)
	{
		%player = teamtracker.teamGroup[0].getObject(%i);
		%clientId = %player.clientId;
		if(!isObject(%player)) return;
		if(%player.isSuperAdmin) %tag = "SA";
		else if(%player.isAdmin) %tag = "A";
		else if(%player.isBot) %tag = "B";
		else %tag = " ";

		%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

		ZTabMenuHUDOBS.addRow(%clientId, %text);
	}

	ZTabMenuHUDOBS.sort();
}

function ZTMHUD::updateTeam1(%this)
{
	ZTabMenuHUDteam1Name.setValue(teamtracker.teamName[1]);

	if(teamtracker.numTeams > 1)
	{
		for(%i=0; %i<teamtracker.teamGroup[1].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[1].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam1.setRowById(%clientId, %text);
		}

		ZTabMenuHUDteam1.sort();
	}
	else
	{
		for(%i=0; %i<teamtracker.teamGroup[1].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[1].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam1.setRowById(%clientId, %text);
		}

		for(%i=0; %i<teamtracker.teamGroup[2].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[2].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam1.setRowById(%clientId, %text);
		}

		ZTabMenuHUDteam1.sort();
	}
}

function ZTMHUD::updateTeam2(%this)
{
	if(teamtracker.numTeams > 1)
	{
		ZTabMenuHUDteam2Name.setValue(teamtracker.teamName[2]);

		for(%i=0; %i<teamtracker.teamGroup[2].getCount(); %i++)
		{
			%player = teamtracker.teamGroup[2].getObject(%i);
			%clientId = %player.clientId;
			if(!isObject(%player)) return;
			if(%player.isSuperAdmin) %tag = "SA";
			else if(%player.isAdmin) %tag = "A";
			else if(%player.isBot) %tag = "B";
			else %tag = " ";

			%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

			ZTabMenuHUDteam2.setRowById(%clientId, %text);
		}

		ZTabMenuHUDteam2.sort();
	}
}

function ZTMHUD::updateOBS(%this)
{
	ZTabMenuHUDOBSname.setValue(teamtracker.teamName[0]);

	for(%i=0; %i<teamtracker.teamGroup[0].getCount(); %i++)
	{
		%player = teamtracker.teamGroup[0].getObject(%i);
		%clientId = %player.clientId;
		if(!isObject(%player)) return;
		if(%player.isSuperAdmin) %tag = "SA";
		else if(%player.isAdmin) %tag = "A";
		else if(%player.isBot) %tag = "B";
		else %tag = " ";

		%text = %tag TAB %player.name TAB %player.score TAB %player.ping TAB %player.packetLoss TAB %player.guid;

		ZTabMenuHUDOBS.setRowById(%clientId, %text);
	}

	ZTabMenuHUDOBS.sort();
}

function ZTMHUD::clearTeam1(%this)
{
	ZTabMenuHUDteam1.clearList();
}

function ZTMHUD::clearTeam2(%this)
{
	if(teamtracker.numTeams > 1) ZTabMenuHUDteam2.clearList();
}

function ZTMHUD::clearOBS(%this)
{
	 ZTabMenuHUDOBS.clearList();
}

function ZTMHUD::buildAll(%this)
{
	commandToServer('getScores');

	ZTMHUD.clearOBS();
	ZTMHUD.buildOBS();

	ZTMHUD.clearTeam1();
	ZTMHUD.buildTeam1();

	ZTMHUD.clearTeam2();
	ZTMHUD.buildTeam2();
}

function ZTMHUD::updateLoop(%this)
{
	commandToServer('getScores');

	ZTMHUD.updateOBS();
	ZTMHUD.updateTeam1();
	ZTMHUD.updateTeam2();
	
	$updateLoop = ZTMHUD.schedule(500, updateLoop);
}

function ZTMHUD::plJoinTeam(%this, %oldTeamID, %newTeamID, %clientID)
{
	if(!$ZTabMenuHUDOn) return;
	cancel($updateLoop);
	commandToServer('getScores');

	switch(%oldTeamID)
	{
		case 0: ZTabMenuHUDOBS.removeRowById(%clientId);
		case 1: ZTabMenuHUDteam1.removeRowById(%clientId);
		case 2: ZTabMenuHUDteam2.removeRowById(%clientId);
	}

	ZTMHUD.buildAll();
	
	$updateLoop = ZTMHUD.schedule(500, updateLoop);
}

function ZTMHUD::plLeavingGame(%this, %oldTeamID, %clientID)
{
	if(!$ZTabMenuHUDOn) return;
	cancel($updateLoop);
	commandToServer('getScores');

	switch(%oldTeamID)
	{
		case 0: ZTabMenuHUDOBS.removeRowById(%clientId);
		case 1: ZTabMenuHUDteam1.removeRowById(%clientId);
		case 2: ZTabMenuHUDteam2.removeRowById(%clientId);
	}

	ZTMHUD.buildAll();
	
	$updateLoop = ZTMHUD.schedule(500, updateLoop);
}

function ZTMHUD::voteFill(%this)
{
	ZTabMenuHUDvoteMenu.key++;
	ZTabMenuHUDvoteMenu.clear();
	ZTabMenuHUDvoteMenu.tourneyChoose = 0;
	commandToServer('GetVoteMenu', ZTabMenuHUDvoteMenu.key);
}

function ZTMHUD::voteFillTeam(%this)
{
	ZTabMenuHUDvoteMenu.key++;
	ZTabMenuHUDvoteMenu.clear();
	ZTabMenuHUDvoteMenu.mode = "team";
	commandToServer('GetTeamList', ZTabMenuHUDvoteMenu.key);
	ZTabMenuHUDvoteCancel.setVisible(true);
}

function ZTMHUD::voteFillMissionType(%this)
{
	ZTabMenuHUDvoteMenu.key++;
	ZTabMenuHUDvoteMenu.clear();
	ZTabMenuHUDvoteMenu.mode = "type";
	commandToServer('GetMissionTypes', ZTabMenuHUDvoteMenu.key);
	ZTabMenuHUDvoteCancel.setVisible(true);
}

function ZTMHUD::voteFillMission(%this, %type, %typeName)
{
	ZTabMenuHUDvoteMenu.key++;
	ZTabMenuHUDvoteMenu.clear();
	ZTabMenuHUDvoteMenu.mode = "mission";
	ZTabMenuHUDvoteMenu.missionType = %type;
	ZTabMenuHUDvoteMenu.typeName = %typeName;
	commandToServer('GetMissionList', ZTabMenuHUDvoteMenu.key, %type);
}

function ZTMHUD::voteFillTimeLimit(%this)
{
	ZTabMenuHUDvoteMenu.key++;
	ZTabMenuHUDvoteMenu.clear();
	ZTabMenuHUDvoteMenu.mode = "timeLimit";
	commandToServer('GetTimeLimitList', ZTabMenuHUDvoteMenu.key);
	ZTabMenuHUDvoteCancel.setVisible(true);
}

function ZTMHUD::voteFillAntiTurtleTimeLimit(%this)
{
	ZTabMenuHUDvoteMenu.key++;
	ZTabMenuHUDvoteMenu.clear();
	ZTabMenuHUDvoteMenu.mode = "turtleLimit";
	commandToServer('GetAntiTurtleTimeList', ZTabMenuHUDvoteMenu.key);
	ZTabMenuHUDvoteCancel.setVisible(true);
}

function ZTMHUD::voteItemMessage(%this, %msgType, %msgString, %key, %voteName, %voteActionMsg, %voteText, %sort)
{
	if (!$ZTabMenuHUDOn || %key != ZTabMenuHUDvoteMenu.key) return;
	
	%index = ZTabMenuHUDvoteMenu.rowCount();
	ZTabMenuHUDvoteMenu.addRow(%index, detag(%voteText));
	if (%sort) ZTabMenuHUDvoteMenu.sort(0);
	$clVoteCmd[%index] = detag(%voteName);
	$clVoteAction[%index] = detag(%voteActionMsg);
}

function ZTMHUD::voteControl(%this)
{
	%id = ZTabMenuHUDvoteMenu.getSelectedId();
	%text = ZTabMenuHUDvoteMenu.getRowTextById(%id);

	switch$ (ZTabMenuHUDvoteMenu.mode)
	{
		case "":
		switch$ ($clVoteCmd[%id])
		{
			case "JoinGame":
				CommandToServer('clientJoinGame');
				schedule(100, 0, ZTabMenuHUDToggle, true);
				return;
            
			case "ChooseTeam":
				ZTMHUD.voteFillTeam();
				return;

			case "VoteTournamentMode":
				ZTabMenuHUDvoteMenu.tourneyChoose = 1;
				ZTMHUD.voteFillMissionType();
				return; 
               
			case "VoteMatchStart":
				startNewVote("VoteMatchStart");
				schedule(100, 0, ZTabMenuHUDToggle, true);
				return;   

			case "MakeObserver":
				commandToServer('ClientMakeObserver');
				schedule(100, 0, ZTabMenuHUDToggle, true);
				return;

			case "VoteChangeMission":
				ZTMHUD.voteFillMissionType();
				return;

			case "VoteChangeTimeLimit":
				ZTMHUD.voteFillTimeLimit();
				return;

			case "VoteAntiTurtleTime":
				ZTMHUD.voteFillAntiTurtleTimeLimit();
				return;
            
			case "Addbot":
				commandToServer('addBot');
				return;
		}

		case "team":
			commandToServer('ClientJoinTeam', %id++);
			schedule(100, 0, ZTabMenuHUDToggle, true);
			return;

		case "type":
			ZTMHUD.voteFillMission($clVoteCmd[%id], %text);
			return;

		case "mission":
			if(!ZTabMenuHUDvoteMenu.tourneyChoose)
			{
				startNewVote("VoteChangeMission", %text, ZTabMenuHUDvoteMenu.typeName, $clVoteCmd[%id], ZTabMenuHUDvoteMenu.missionType);
			}
			else
			{
				startNewVote("VoteTournamentMode", %text, ZTabMenuHUDvoteMenu.typeName, $clVoteCmd[%id], ZTabMenuHUDvoteMenu.missionType);
				ZTabMenuHUDvoteMenu.tourneyChoose = 0;
			}
			ZTabMenuHUDvoteMenu.reset();
			return;

		case "timeLimit":
			startNewVote("VoteChangeTimeLimit", $clVoteCmd[%id]);
			ZTabMenuHUDvoteMenu.reset();
			return;

		case "turtleLimit":
			startNewVote("VoteAntiTurtleTimeLimit", $clVoteCmd[%id]);
			ZTabMenuHUDvoteMenu.reset();
			return;
	}

	startNewVote($clVoteCmd[%id], $clVoteAction[%id]);

	ZTMHUD.voteFill();
}

function ZTabMenuHUDplayerActionDlg::onWake(%this)
{
	ZTabMenuHUD.playerDialogOpen = true;
	ZTMHUD.playerPopupMenu();
}

function ZTabMenuHUDplayerActionDlg::onSleep(%this)
{
	ZTabMenuHUD.playerDialogOpen = false;
}

function ZTabMenuHUDplayerPopup::onSelect(%this, %id, %text)
{
	//1	text mute
	//2	vote admin
	//3	vote kick
	//8	force join
	//9	disable voice com
	//12	observe player
	//5	a force observer
	//6	a switch team1
	//7	a switch team2
	//13	a warn
	//14	a strip admin
	//15	a pm
	//16	a client info
	//4	sa ban
	//10	sa add to admin
	//11	sa add to sa
	//17	sa gag player
	//18	sa freeze player
	//19	sa boot player
	//20	sa explode player

	switch(%id)
	{
		case 1:		commandToServer('togglePlayerMute', %this.player.clientId);
		
		case 2:		MessageBoxYesNo("CONFIRM", "Are you sure you want to make " @ %this.player.name @ " an admin?", "ZTMHUD.playerVote(VoteAdminPlayer, " @ %this.player.clientId @ ");");
	
		case 3:		MessageBoxYesNo("CONFIRM", "Are you sure you want to kick " @ %this.player.name @ "?", "ZTMHUD.playerVote(VoteKickPlayer, " @ %this.player.clientId @ ");");
		
		case 4:		MessageBoxYesNo("CONFIRM", "Are you sure you want to ban " @ %this.player.name @ "?", "ZTMHUD.playerVote(BanPlayer, " @ %this.player.clientId @ ");");
		
		case 5:		commandToServer('forcePlayerToObserver', %this.player.clientId);
		
		case 6:		commandToServer('changePlayersTeam', %this.player.clientId, 1);
				ZTMHUD.voteFill();
		
		case 7:		commandToServer('changePlayersTeam', %this.player.clientId, 2);
				ZTMHUD.voteFill();
		
		case 8:		commandToServer('clientAddToGame', %this.player.clientId);
		
		case 9:		commandToServer('ListenTo', %this.player.clientId, !%this.player.voiceEnabled, true);
	
		case 10:	MessageBoxYesNo("CONFIRM", "Are you sure you want to add " @ %this.player.name @ " to the admin list?", "commandToServer('AddToAdminList', %this.player);");
		
		case 11:	MessageBoxYesNo("CONFIRM", "Are you sure you want to add " @ %this.player.name @ " to the super-admin list?" , "commandToServer('AddToSuperAdminList', %this.player);");
			
		case 12:	commandToServer('processGameLink', %this.player.clientId);

		case 13:	commandToServer('warnPlayer', %this.player);

		case 14:	commandToServer('stripAdmin', %this.player);

		case 15:	ZTMHUD.pm(%this.player);

		case 16:	commandToServer('printClientInfo', %this.player);

		case 17:	commandToServer('togglePlayerGag', %this.player.clientId);

		case 18:	commandToServer('togglePlayerFreeze', %this.player.clientId);

		case 19:	commandToServer('bootToTheRear', %this.player.clientId);

		case 20:	commandToServer('explodePlayer', %this.player.clientId);

		case 900:	LinkEMail(baseName(%this.player));

		case 901:	LinkAddBuddy(baseName(%this.player), TWBText, "addBuddy");
	}

	canvas.popDialog(ZTabMenuHUDplayerActionDlg);
}

function ZTMHUD::pm(%this, %player)
{
	new ShellPaneCtrl(ZTabMenuHUDpmPane)
	{
		profile = "ShellPaneProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "500 400";
		extent = "300 200";
		minExtent = "8 8";
		visible = "1";
		text = "Private Message";

		new ShellTextEditCtrl(ZTabMenuHUDpmText) {
			profile = "NewTextEditProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "100 25";
			extent = "100 38";
			minExtent = "20 20";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			variable = "%text";
			helpTag = "0";
			longTextBuffer = "0";
			maxLength = "255";
			historySize = "0";
			password = "0";
			IRCName = "0";
			tabComplete = "0";
			glowOffset = "9 9";
		};
		new ShellBitmapButton() {
			profile = "ShellButtonProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "75 75";
			extent = "75 38";
			minExtent = "32 15";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			command = "canvas.popdialog(ZTabMenuHUDpmPane);";
			helpTag = "0";
			text = "Cancel";
			simpleStyle = "0";
		};
		new ShellBitmapButton() {
			profile = "ShellButtonProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "125 75";
			extent = "75 38";
			minExtent = "32 15";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			command = "commandToServer('privateMessageSent', %player, %text); canvas.popdialog(ZTabMenuHUDpmPane);";
			helpTag = "0";
			text = "Send";
			simpleStyle = "0";
		};	
	};

	canvas.pushdialog(ZTabMenuHUDpmPane);
}

function ZTMHUD::playerPopupMenu(%this)
{
	ZTabMenuHUDplayerPopup.key++;
	ZTabMenuHUDplayerPopup.clear();

	ZTabMenuHUDplayerPopup.add(ZTabMenuHUDplayerPopup.player.name, 0);
	ZTabMenuHUDplayerPopup.add("____________________", 0);

	ZTMHUD.setNormalMenu(ZTabMenuHUDplayerPopup.player);
	if(teamtracker.myId.isAdmin) ZTMHUD.setAdminMenu(ZTabMenuHUDplayerPopup.player);
	if(teamtracker.myId.isSuperAdmin) ZTMHUD.setSuperAdminMenu(ZTabMenuHUDplayerPopup.player);

//	commandToServer('GetPlayerPopupMenu', ZTabMenuHUDplayerPopup.player.clientId, ZTabMenuHUDplayerPopup.key);
}

function ZTMHUD::setNormalMenu(%this, %player)
{
	if((!teamtracker.myId.isAdmin || !teamtracker.myId.isSuperAdmin) && teamtracker.myId !$= ZTabMenuHUDplayerPopup.player.clientId)
	{
		%line = detag("Vote to kick");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 3);

		%line = detag("Vote to admin");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 2);
	}

	if(teamtracker.myId !$= ZTabMenuHUDplayerPopup.player.clientId)
	{
		%line = detag("Toggle mute text");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 1);

		%line = detag("Toggle mute voice");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 9);

		%line = detag("Observe player");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 12);

		%line = detag("Tmail");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 900);

		%line = detag("Add to buddies");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 901);
	}
	else ZTMHUD.setPersonalMenu();
}

function ZTMHUD::setAdminMenu(%this, %player)
{
	ZTabMenuHUDplayerPopup.add("	", 0);
	ZTabMenuHUDplayerPopup.add("Admin options", 0);
	ZTabMenuHUDplayerPopup.add("____________________", 0);

	%line = detag("Force to " @ teamtracker.teamName[1]);
	ZTabMenuHUDplayerPopup.add("	" @ %line, 6);

	%line = detag("Force to " @ teamtracker.teamName[2]);
	ZTabMenuHUDplayerPopup.add("	" @ %line, 7);

	%line = detag("Warn player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 13);

	%line = detag("Kick player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 3);

	%line = detag("Admin player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 2);

	%line = detag("WHOIS player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 16);

	%line = detag("PM player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 15);
}

function ZTMHUD::setSuperAdminMenu(%this, %player)
{
	ZTabMenuHUDplayerPopup.add("	", 0);
	ZTabMenuHUDplayerPopup.add("Super-admin options", 0);
	ZTabMenuHUDplayerPopup.add("____________________", 0);

	%line = detag("Ban player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 4);

	if(%player.isAdmin)
	{
		%line = detag("De-admin player");
		ZTabMenuHUDplayerPopup.add("	" @ %line, 14);
	}

	%line = detag("Toggle gag player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 17);

	%line = detag("Toggle freeze player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 18);

	%line = detag("Smack player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 19);

	%line = detag("Explode player");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 20);

	%line = detag("Add to admin list");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 10);

	%line = detag("Add to super-admin list");
	ZTabMenuHUDplayerPopup.add("	" @ %line, 11);	
}

function ZTMHUD::setPersonalMenu(%this)
{
	ZTabMenuHUDplayerPopup.add("	", 0);
	ZTabMenuHUDplayerPopup.add("Personal options", 0);
	ZTabMenuHUDplayerPopup.add("____________________", 0);
}

function ZTMHUD::playerPopupMessage(%this, %msgType, %msgString, %key, %voteName, %voteActionMsg, %voteText, %popupEntryId)
{
	if(!$ZTabMenuHUDOn || %key != ZTabMenuHUDplayerPopup.key) return;
	ZTabMenuHUDplayerPopup.add("	" @ detag(%voteText), %popupEntryId);
}

function ZTMHUD::playerVote(%this, %voteType, %playerId)
{
	startNewVote(%voteType, %playerId, 0, 0, 0, true);
	ZTMHUD.voteFill();
}

function ZTabMenuHUD::onWake(%this)
{
	$ZTabMenuHUDOn = true;

	if(!%this.init)
	{
		ZTabMenuHUDOBS.setSortColumn($pref::ZTabMenuHUDOBS::SortColumnKey);
		ZTabMenuHUDOBS.setSortIncreasing($pref::ZTabMenuHUDOBS::SortInc);
		ZTabMenuHUDteam1.setSortColumn($pref::ZTabMenuHUDteam1::SortColumnKey);
		ZTabMenuHUDteam1.setSortIncreasing($pref::ZTabMenuHUDteam1::SortInc);
		ZTabMenuHUDteam2.setSortColumn($pref::ZTabMenuHUDteam2::SortColumnKey);
		ZTabMenuHUDteam2.setSortIncreasing($pref::ZTabMenuHUDteam2::SortInc);

		%this.init = true;
	}

	ZTMHUD.updateLoop();
	ZTMHUD.voteFill();

	GlobalActionMap.copyBind(moveMap, ZTabMenuHUDToggle);
}

function ZTabMenuHUD::onSleep(%this)
{
	$ZTabMenuHUDOn = false;

	cancel($updateLoop);

	ZTMHUD.clearOBS();
	ZTMHUD.clearTeam1();
	if(teamtracker.numTeams > 1) ZTMHUD.clearTeam2();

	clearMapping(GlobalActionMap, ZTabMenuHUDToggle);
}

function ZTabMenuHUD::onAdd(%this)
{
	new GuiControl(ZTabMenuHUDPlayerActionDlg)
	{
		profile = "GuiModelessDialogProfile";
		horizSizing = "width";
		vertSizing = "height";
		position = "0 0";
		extent = "640 480";
		minExtent = "8 8";
		visible = "1";
		setFirstResponder = "0";
		modal = "1";

		new ShellPopupMenu(ZTabMenuHUDPlayerPopup)
		{
			profile = "ShellPopupProfile";
			position = "0 0";
			extent = "0 0";
			minExtent = "0 0";
			visible = "1";
			maxPopupHeight = "200";
			noButtonStyle = "1";
		};
	};
}

function ZTabMenuHUDplayerPopup::onCancel(%this)
{
	canvas.popDialog(ZTabMenuHUDplayerActionDlg);
}

function ZTabMenuHUDvoteMenu::reset(%this)
{
	%this.mode = "";
	%this.tourneyChoose = 0;
	ZTabMenuHUDvoteCancel.setVisible(false);
	ZTMHUD.voteFill();
}

function ZTabMenuHUDteam1::onColumnResize(%this, %col, %size)
{
	$pref::ZTabMenuHUDteam1::Column[%this.getColumnKey(%col)] = %size;
}

function ZTabMenuHUDteam1::onSetSortKey(%this, %key, %increasing)
{
	$pref::ZTabMenuHUDteam1::SortColumnKey = %key;
	$pref::ZTabMenuHUDteam1::SortInc = %increasing;
}

function ZTabMenuHUDteam1::saveColumns(%this)
{
	%count = %this.getNumColumns();
	for (%col = 0; %col < %count; %col++)
	{
		$pref::ZTabMenuHUDteam1::Column[%this.getColumnKey(%col)] = %this.getColumnWidth(%col);
	}
}

function ZTabMenuHUDteam1::onRightMouseDown(%this, %column, %row, %mousePos)
{
	%clientId = %this.getRowId(%row);
	ZTabMenuHUDplayerPopup.player = $PlayerList[%clientId];

	if(ZTabMenuHUDplayerPopup.player !$= "")
	{
		ZTabMenuHUDplayerPopup.position = %mousePos;
		canvas.pushDialog(ZTabMenuHUDplayerActionDlg);
		ZTabMenuHUDplayerPopup.forceOnAction();
	}
}

function ZTabMenuHUDteam2::onColumnResize(%this, %col, %size)
{
	$pref::ZTabMenuHUDteam2::Column[%this.getColumnKey(%col)] = %size;
}

function ZTabMenuHUDteam2::onSetSortKey(%this, %key, %increasing)
{
	$pref::ZTabMenuHUDteam2::SortColumnKey = %key;
	$pref::ZTabMenuHUDteam2::SortInc = %increasing;
}

function ZTabMenuHUDteam2::saveColumns(%this)
{
	%count = %this.getNumColumns();
	for (%col = 0; %col < %count; %col++)
	{
		$pref::ZTabMenuHUDteam2::Column[%this.getColumnKey(%col)] = %this.getColumnWidth(%col);
	}
}

function ZTabMenuHUDteam2::onRightMouseDown(%this, %column, %row, %mousePos)
{
	%clientId = %this.getRowId(%row);
	ZTabMenuHUDplayerPopup.player = $PlayerList[%clientId];

	if(ZTabMenuHUDplayerPopup.player !$= "")
	{
		ZTabMenuHUDplayerPopup.position = %mousePos;
		canvas.pushDialog(ZTabMenuHUDplayerActionDlg);
		ZTabMenuHUDplayerPopup.forceOnAction();
	}
}

function ZTabMenuHUDOBS::onColumnResize(%this, %col, %size)
{
	$pref::ZTabMenuHUDOBS::Column[%this.getColumnKey(%col)] = %size;
}

function ZTabMenuHUDOBS::onSetSortKey(%this, %key, %increasing)
{
	$pref::ZTabMenuHUDOBS::SortColumnKey = %key;
	$pref::ZTabMenuHUDOBS::SortInc = %increasing;
}

function ZTabMenuHUDOBS::saveColumns(%this)
{
	%count = %this.getNumColumns();
	for (%col = 0; %col < %count; %col++)
	{
		$pref::ZTabMenuHUDOBS::Column[%this.getColumnKey(%col)] = %this.getColumnWidth(%col);
	}
}

function ZTabMenuHUDOBS::onRightMouseDown(%this, %column, %row, %mousePos)
{
	%clientId = %this.getRowId(%row);
	ZTabMenuHUDplayerPopup.player = $PlayerList[%clientId];

	if(ZTabMenuHUDplayerPopup.player !$= "")
	{
		ZTabMenuHUDplayerPopup.position = %mousePos;
		canvas.pushDialog(ZTabMenuHUDplayerActionDlg);
		ZTabMenuHUDplayerPopup.forceOnAction();
	}
}

ZTMHUD.setup();